@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2007-2017 by Dominique Dumont.
+# This software is Copyright (c) 2007-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -37,7 +37,7 @@
 
         'element' => [
 
-            [qw/class_description license/] => {
+            [qw/class_description license gist/] => {
                 type       => 'leaf',
                 value_type => 'string',
             },
@@ -62,7 +62,7 @@
                         code => 'not defined $_ or eval{Mouse::Util::load_class($_)}; not $@;',
                         msg  => 'Error while loading $_ class ',
                     },
-                    "2_class_inherit" => {
+                   "2_class_inherit" => {
                         code => 'not defined $_ or $_->isa("Config::Model::Node")',
                         msg  => 'class $_ must inherit Config::Model::Node',
                     }
@@ -103,26 +103,9 @@
 
             rw_config => {
                 type              => 'node',
-                config_class_name => 'Itself::ConfigRead',
+                config_class_name => 'Itself::ConfigReadWrite',
             },
 
-            'read_config' => {
-                type  => 'list',
-                status => 'deprecated',
-                cargo => {
-                    type              => 'node',
-                    config_class_name => 'Itself::ConfigRead',
-                },
-            },
-
-            'write_config' => {
-                type  => 'list',
-                status => 'deprecated',
-                cargo => {
-                    type              => 'node',
-                    config_class_name => 'Itself::ConfigWrite',
-                },
-            },
             'accept' => {
                 type       => 'hash',
                 index_type => 'string',
@@ -135,14 +118,18 @@
         ],
         'description' => [
             element => "Specify the elements names of this configuration class.",
+            gist => 'String used to construct a summary of the content of a node. This '
+                .'parameter is used by user interface to show users the gist of the '
+                .'content of this node. This parameter has no other effect. This string '
+                .'may contain element values in the form "C<{foo} or {bar}>". When '
+                .'constructing the gist, C<{foo}> is replaced by the value of element '
+                .'C<foo>. Likewise for C<{bar}>.',
             include => "Include the element description of another class into this class.",
             include_after => "insert the included elements after a specific element. "
             . "By default, included elements are placed before all other elements.",
             include_backend => "Include the read/write specification of another class into this class.",
             class_description => "Explain the purpose of this configuration class. This description is re-used to generate the documentation of your configuration class. You can use pod markup to format your description. See L<perlpod> for details.",
             rw_config => "Specify the backend used to read and write configuration data. See L<Config::Model::BackendMgr> for details",
-            read_config => "Deprecated - specify the Perl class(es) and function(s) used to read configuration data. The specified functions are tried in sequence to get configuration data. ",
-            write_config => "Deprecated - Specify the Perl class and function used to write configuration data.",
             generated_by => "When set, this class was generated by some program. You should not edit "
                 ."this class as your modifications may be clobbered later on when the class is regenerated.",
             accept => "Specifies names of the elements this configuration class accepts as valid. "
@@ -227,6 +214,22 @@
                }
             },
 
+            'function' => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                status     => 'deprecated',
+                level      => 'hidden',
+                warp       => {
+                    follow => '- backend',
+                    rules  => [
+                        custom => {
+                            level            => 'normal',
+                            upstream_default => 'read',
+                        }
+                    ],
+                }
+            },
+
             'auto_create' => {
                 type             => 'leaf',
                 value_type       => 'boolean',
@@ -450,49 +453,6 @@
 
     ],
 
-    [
-        name    => 'Itself::ConfigRead',
-        include => "Itself::ConfigReadWrite",
-
-        'element' => [
-            'function' => {
-                type       => 'leaf',
-                value_type => 'uniline',
-                level      => 'hidden',
-                warp       => {
-                    follow => '- backend',
-                    rules  => [
-                        custom => {
-                            level            => 'normal',
-                            upstream_default => 'read',
-                        }
-                    ],
-                }
-            },
-        ],
-    ],
-
-    [
-        name    => 'Itself::ConfigWrite',
-        include => "Itself::ConfigReadWrite",
-
-        'element' => [
-            'function' => {
-                type       => 'leaf',
-                value_type => 'uniline',
-                level      => 'hidden',
-                warp       => {
-                    follow => '- backend',
-                    rules  => [
-                        custom => {
-                            level            => 'normal',
-                            upstream_default => 'write',
-                        }
-                    ],
-                }
-            },
-        ],
-    ],
     [
         name => 'Itself::ConfigAccept',
 
